@@ -17,6 +17,7 @@ import (
 	configv1 "github.com/operator-framework/operator-marketplace/pkg/apis/config/v1"
 	"github.com/operator-framework/operator-marketplace/pkg/catalogsourceconfig"
 	"github.com/operator-framework/operator-marketplace/pkg/controller"
+	"github.com/operator-framework/operator-marketplace/pkg/controller/options"
 	"github.com/operator-framework/operator-marketplace/pkg/defaults"
 	"github.com/operator-framework/operator-marketplace/pkg/migrator"
 	"github.com/operator-framework/operator-marketplace/pkg/operatorhub"
@@ -141,8 +142,18 @@ func main() {
 		}
 	}
 
+	stopCh := signals.SetupSignalHandler()
+
+	var statusReporter status.Reporter = &status.NoOpReporter{}
+	if clusterOperatorName != "" {
+		statusReporter, err = status.NewReporter(cfg, mgr, namespace, clusterOperatorName, os.Getenv("RELEASE_VERSION"), stopCh)
+		if err != nil {
+			exit(err)
+		}
+	}
+
 	// Setup all Controllers
-	if err := controller.AddToManager(mgr); err != nil {
+	if err := controller.AddToManager(mgr, options.ControllerOptions{SyncSender: statusReporter}); err != nil {
 		exit(err)
 	}
 
@@ -175,10 +186,10 @@ func main() {
 		exit(err)
 	}
 
-	stopCh := signals.SetupSignalHandler()
-
 	// set ClusterOperator status to report Migration
-	status.ReportMigration(cfg, mgr, namespace, os.Getenv("RELEASE_VERSION"), stopCh)
+	if err := statusReporter.ReportMigration(); err != nil {
+		exit(err)
+	}
 
 	client, err := client.New(cfg, client.Options{})
 	if err != nil {
@@ -193,7 +204,7 @@ func main() {
 	}
 
 	// statusReportingDoneCh will be closed after the operator has successfully stopped reporting ClusterOperator status.
-	statusReportingDoneCh := status.StartReporting(cfg, mgr, namespace, os.Getenv("RELEASE_VERSION"), stopCh)
+	statusReportingDoneCh := statusReporter.StartReporting()
 
 	go registrySyncer.Sync(stopCh)
 	go catalogsourceconfig.Syncer.Sync(stopCh)
